@@ -6,17 +6,17 @@ Encodeable_letters = r'''aAbBcCdDeEfFgGhHiIjJkKlLmMnNoOpPqQrRsStTuUvVwWxXyYzZ123
 class TwoWayDict(dict):
     def __init__(self, my_dict):
         dict.__init__(self, my_dict)
-        self.rev_dict = {v : k for k,v in my_dict.items()}
+        self.reverse = {v : k for k,v in my_dict.items()}
 
     def __setitem__(self, key, value):
         dict.__setitem__(self, key, value)
-        self.rev_dict.__setitem__(value, key)
+        self.reverse.__setitem__(value, key)
 
     def pop(self, key):
-        self.rev_dict.pop(self[key])
+        self.reverse.pop(self[key])
         dict.pop(self, key)
     def add(self,key,value):
-        self.rev_dict[value] = key
+        self.reverse[value] = key
         dict[value] = key
 class Encoding():
     '''A way to generate a encoding for your purposes. \n
@@ -55,7 +55,8 @@ class RandomEncoding():
             x = x + self.rate
             self.encodingnormal[letter] = x
         self.encoding = TwoWayDict(self.encodingnormal)
-
+x = TwoWayDict({'a':1})
+x.reverse[1]
 Gen2=[]
 GTX2 = []   
 ichorrev = {
